<?php
/**
Admin area controller
**/
class Admin extends CI_Controller {
	/**
	Admin area controller
	**/
	function __construct() {
		parent::__construct();
		$this->load->model('admin_model');
		$this->load->library('session');
		$this->load->helper('url');
		$this->load->helper('postmaker');
	}
	
	function index() {
		//do nothing
	}
	
	function doLogin() {
		/**
		Process for logging user.  Requires 2 post variables: user & password 
		**/
		$vars = $this->input->post();
		$user = $vars['username'];
		$pass = $vars['password'];
		$login = $this->admin_model->doLogin($user, $pass);
		if ($login == 1) {
			redirect('/a/manage_panel', 'refresh');
		} else {
			redirect('/a/manage_panel/login', 'refresh');
		}
	}
	
	function doLogout() {
		/**
		Process for logging out user.  Requires no arguements 
		**/
		foreach ($_SESSION as $key=>$value) {
			unset($_SESSION[$key]);
		}
		redirect('/a/manage_panel/login', 'refresh');
	}
	
	function doSaveMedia() {
		/**
		Function to upload files to the media center
		**/
		$this->load->helper('fileio');
		$result = $this->admin_model->doSaveMedia();
		redirect('/a/manage_panel/media-gallery?url=' . urlencode($result), 'refresh');
	}
	
	function doAddPage() {
		/**
		Process for adding a new page.  Requires the following post variables:
		Title
		Content
		**/
		$usr = $this->admin_model->checkAdminLogin();
		if ($usr == 0) {
			redirect('/a/manage_panel/login', 'refresh');
			die('Unauthorized Access');
		}
		$vars = $this->input->post();
		if (!isset($vars['title']) || !isset($vars['content'])) {
			redirect_back();
		} else {
			$args = $vars;
			$result = $this->admin_model->doAddPage($args);
			if ($result) {
				redirect('/a/manage_panel/view-pages', 'refresh');
			}
		}
	}
	
	function doEditPage() {
		/**
		Process for editing a page.  Requires the following post variables:
		Title
		Content
		SysID
		Slug
		**/
		$usr = $this->admin_model->checkAdminLogin();
		if ($usr == 0) {
			redirect('/a/manage_panel/login', 'refresh');
			die('Unauthorized Access');
		}
		$vars = $this->input->post();
		if (!isset($vars['title']) || !isset($vars['content']) || !isset($vars['sys_id']) || !isset($vars['slug'])) {
			redirect_back();
		} else {
			$args = $vars;
			$result = $this->admin_model->doEditPage($args);
			if ($result == 1) {
				redirect('/a/manage_panel/view-pages', 'refresh');
			} else {
				redirect('/a/manage_panel/view-pages', 'refresh');
			}
		}
	}
	
	function doDelPage() {
		/**
		Process for Deleting a page.  Requires sys_id post variable
		**/
		$usr = $this->admin_model->checkAdminLogin();
		if ($usr == 0) {
			redirect('/a/manage_panel/login', 'refresh');
			die('Unauthorized Access');
		}
		$vars = $this->input->post();
		if (!isset($vars['sys_id']) && $vars['sys_id'] != '') {
			redirect_back();
		} else {
			$sys_id = intval($vars['sys_id']);
			$result = $this->admin_model->doDelPage($sys_id);
			if ($result == 1) {
				redirect('/a/manage_panel/view-pages', 'refresh');
			} else {
				redirect('/a/manage_panel/view-pages', 'refresh');
			}
		}
	}
	
	function doAddPost() {
		/**
		Process for adding a new post.  Requires the following post variables:
		Title
		Content
		**/
		$usr = $this->admin_model->checkAdminLogin();
		if ($usr == 0) {
			redirect('/a/manage_panel/login', 'refresh');
			die('Unauthorized Access');
		}
		$vars = $this->input->post();
		if (!isset($vars['title']) || !isset($vars['content'])) {
			redirect_back();
		} else {
			$args = $vars;
			$result = $this->admin_model->doAddPost($args);
			if ($result == 1) {
				redirect('/a/manage_panel/view-posts', 'refresh');
			} else {
				redirect('/a/manage_panel/view-posts', 'refresh');
			}
		}
	}
	
	function doEditPost() {
		/**
		Process for editing a post.  Requires the following post variables:
		Title
		Content
		SysID
		Slug
		cat
		**/
		$usr = $this->admin_model->checkAdminLogin();
		if ($usr == 0) {
			redirect('/a/manage_panel/login', 'refresh');
			die('Unauthorized Access');
		}
		$vars = $this->input->post();
		if (!isset($vars['title']) || !isset($vars['content']) || !isset($vars['sys_id']) || !isset($vars['slug'])) {
			redirect_back();
		} else {
			$args = $vars;
			$result = $this->admin_model->doEditPost($args);
			if ($result == 1) {
				redirect('/a/manage_panel/view-posts', 'refresh');
			} else {
				redirect('/a/manage_panel/view-posts', 'refresh');
			}
		}
	}
	
	function doDelPost() {
		/**
		Process for Deleting a page.  Requires sys_id post variable
		**/
		$usr = $this->admin_model->checkAdminLogin();
		if ($usr == 0) {
			redirect('/a/manage_panel/login', 'refresh');
			die('Unauthorized Access');
		}
		$vars = $this->input->post();
		if (!isset($vars['sys_id']) && $vars['sys_id'] != '') {
			redirect_back();
		} else {
			$sys_id = intval($vars['sys_id']);
			$result = $this->admin_model->doDelPost($sys_id);
			if ($result == 1) {
				redirect('/a/manage_panel/view-posts', 'refresh');
			} else {
				redirect('/a/manage_panel/view-posts', 'refresh');
			}
		}
	}
	
	function doAddBlock() {
		/**
		Process for adding a new block.  Requires the following post variables:
		Title
		Content
		**/
		$usr = $this->admin_model->checkAdminLogin();
		if ($usr == 0) {
			redirect('/a/manage_panel/login', 'refresh');
			die('Unauthorized Access');
		}
		$vars = $this->input->post();
		if (!isset($vars['title']) || !isset($vars['content'])) {
			redirect_back();
		} else {
			$args = $vars;
			$result = $this->admin_model->doAddBlock($args);
			if ($result) {
				redirect('/a/manage_panel/view-blocks', 'refresh');
			}
		}
	}
	
	function doEditBlock() {
		/**
		Process for editing a block.  Requires the following post variables:
		Title
		Content
		SysID
		Slug
		**/
		$usr = $this->admin_model->checkAdminLogin();
		if ($usr == 0) {
			redirect('/a/manage_panel/login', 'refresh');
			die('Unauthorized Access');
		}
		$vars = $this->input->post();
		if (!isset($vars['title']) || !isset($vars['content']) || !isset($vars['sys_id'])) {
			redirect_back();
		} else {
			$args = $vars;
			$result = $this->admin_model->doEditBlock($args);
			if ($result == 1) {
				redirect('/a/manage_panel/view-blocks', 'refresh');
			} else {
				redirect('/a/manage_panel/view-blocks', 'refresh');
			}
		}
	}
	
	function doDelBlock() {
		/**
		Process for Deleting a page.  Requires sys_id post variable
		**/
		$usr = $this->admin_model->checkAdminLogin();
		if ($usr == 0) {
			redirect('/a/manage_panel/login', 'refresh');
			die('Unauthorized Access');
		}
		$vars = $this->input->post();
		if (!isset($vars['sys_id']) && $vars['sys_id'] != '') {
			redirect_back();
		} else {
			$sys_id = intval($vars['sys_id']);
			$result = $this->admin_model->doDelBlock($sys_id);
			if ($result == 1) {
				redirect('/a/manage_panel/view-blocks', 'refresh');
			} else {
				redirect('/a/manage_panel/view-blocks', 'refresh');
			}
		}
	}
	
	function doAddStaff() {
		/**
		Process for adding a new staff member.  Requires the following post variables:
		Name (required)
		Title (optional)
		Content (required)
		img (optional)
		**/
		$usr = $this->admin_model->checkAdminLogin();
		if ($usr == 0) {
			redirect('/a/manage_panel/login', 'refresh');
			die('Unauthorized Access');
		}
		$vars = $this->input->post();
		if (!isset($vars['name']) || !isset($vars['content'])) {
			redirect_back();
		} else {
			$args = $vars;
			$result = $this->admin_model->doAddStaff($args);
			if ($result) {
				redirect('/a/manage_panel/view-staff', 'refresh');
			}
		}
	}
	
	function doEditStaff() {
		/**
		Process for editing a block.  Requires the following post variables:
		Title
		Content
		SysID
		Slug
		**/
		$usr = $this->admin_model->checkAdminLogin();
		if ($usr == 0) {
			redirect('/a/manage_panel/login', 'refresh');
			die('Unauthorized Access');
		}
		$vars = $this->input->post();
		if (!isset($vars['name']) || !isset($vars['content']) || !isset($vars['sys_id'])) {
			redirect_back();
		} else {
			$args = $vars;
			$result = $this->admin_model->doEditStaff($args);
			if ($result == 1) {
				redirect('/a/manage_panel/view-staff', 'refresh');
			} else {
				redirect('/a/manage_panel/view-staff', 'refresh');
			}
		}
	}
	
	function doDelStaff() {
		/**
		Process for Deleting a page.  Requires sys_id post variable
		**/
		$usr = $this->admin_model->checkAdminLogin();
		if ($usr == 0) {
			redirect('/a/manage_panel/login', 'refresh');
			die('Unauthorized Access');
		}
		$vars = $this->input->post();
		if (!isset($vars['sys_id']) && $vars['sys_id'] != '') {
			redirect_back();
		} else {
			$sys_id = intval($vars['sys_id']);
			$result = $this->admin_model->doDelStaff($sys_id);
			if ($result == 1) {
				redirect('/a/manage_panel/view-staff', 'refresh');
			} else {
				redirect('/a/manage_panel/view-staff', 'refresh');
			}
		}
	}
	
	function doApproveTestimonials() {
		$usr = $this->admin_model->checkAdminLogin();
		if ($usr == 0) {
			redirect('/a/manage_panel/login', 'refresh');
			die('Unauthorized Access');
		}
		$vars = $this->input->post();
		$sys_id = $vars['sys_id'];
		$status = $vars['status'];
		$result = $this->admin_model->doApproveTestimonials($sys_id, $status);
		if ($result == 1) {
			redirect('/a/manage_panel/testimonials', 'refresh');
		} else {
			redirect('/a/manage_panel/testimonials', 'refresh');
		}
	}
}
?>