<?php
/**
Pages controller for handing the view processing.
*/
class Pages extends CI_Controller {
	/**
	Pages controller for handling the view processing.
	*/
	function __construct() {
		parent::__construct();
		$this->load->model('pages_model');
		$this->load->library('session');
		$this->load->helper('url');
	}
	
	function index() {
		/**
		Defaults to function viewPage() with Type of "pages" and slug of "home"
		*/
		$this->viewPage('pages','home');
	}
	
	function viewPage($type = "pages", $slug = "home", $input_var = NULL) {
		/**
		function for handling the loading of pages.  It requires 2 inputs: type (mvc category) and slug (file name) and can accept 1 optional arguement: $input_var.
		Additional Optional Variables Used:
			$data['js'] = Javascript to execute on the specific type or page
			$data['title'] = Page title for use in template and <title></title> blocks
			$data['meta'] = Meta content for the header
			$data['menu'] = The slug of the page for marking the menu as active on views
			$header = Array of files to execute in order for the header
			$footer = Array of files to execute in order for the footer
		*/
		$data['page_content'] = $this->pages_model->getPage($slug, $type);
		$data['menu'] = $slug;
		$data['title'] = "Momma Goldberg's Deli - Franchising Opportunity";
		$data['meta'] = '<meta name="keywords" content="Momma Goldbergs Franchise Opportunity" /><meta name="description" content="Momma Holdbergs Franchise Opportunity" />';
		if ($type == "pages") {
			if ($slug == "home") {
				$data['js'] = '<script></script>';
				$header[0] = "includes/header.php";
				$footer[0] = "includes/footer.php";
			}
			if ($slug == "staff") {
				$this->load->model('staff_model');
				$data['staff'] = $this->staff_model->getStaffs();
				$data['title'] = "Our Staff - Momma Goldberg's Deli";
				$header[0] = "includes/header.php";
				$footer[0] = "includes/footer.php";
			}
			switch ($slug) {
				case "get-started":
					$data['title'] = "Get Started - Momma Goldberg's Deli";
					$header[0] = "includes/header.php";
					$footer[0] = "includes/footer.php";
				break;
				case "history":
					$data['founder'] = $this->pages_model->getBlock(1);
					$data['title'] = "Our History - Momma Goldberg's Deli";
					$header[0] = "includes/header.php";
					$footer[0] = "includes/footer.php";
				break;
				case "ideal-candidate":
					$data['title'] = "Ideal Franchise Owner - Momma Goldberg's Deli";
					$header[0] = "includes/header.php";
					$footer[0] = "includes/footer.php";
				break;
				case "process":
					$data['title'] = "The Process - Momma Goldberg's Deli";
					$header[0] = "includes/header.php";
					$footer[0] = "includes/footer.php";
				break;
				case "support":
					$data['title'] = "Support - Momma Goldberg's Deli";
					$header[0] = "includes/header.php";
					$footer[0] = "includes/footer.php";
				break;
				case "territory":
					$data['title'] = "Territory Map - Momma Goldberg's Deli";
					$header[0] = "includes/header.php";
					$footer[0] = "includes/footer.php";
				break;
				case "why":
					$data['title'] = "Why Momma Goldberg's - Momma Goldberg's Deli";
					$header[0] = "includes/header.php";
					$footer[0] = "includes/footer.php";
				break;
			}
		}
		
		if ($type == "admin") {
			$this->load->model('admin_model');
			$header[0] = "includes/admin-header.php";
			$header[1] = "includes/admin-wrapper-open.php";
			$footer[0] = "includes/admin-wrapper-close.php";
			$footer[1] = "includes/admin-footer.php";
			$chklogin = $this->admin_model->checkAdminLogin();
			$allowed = array('login', 'doLogin');
			$data['js'] = '';
			
			if ($chklogin == 0 && !in_array($slug, $allowed)) {
				$slug = 'login';
				redirect('/a/manage_panel/login', 'refresh');
			}
			
			$editor = array('edit-page', 'edit-post', 'new-page', 'new-post', 'edit-block', 'new-block');
			if (in_array($slug, $editor)) {
				$data['js'] = '
				<script src="/template/js/tinymce/tinymce.min.js"></script>
				<script type="text/javascript">
				tinymce.init({
				  selector: ".mce",
				  height: 500,
				  toolbar1: "undo redo | styleselect | bold italic | alignleft aligncenter alignright alignjustify | bullist numlist outdent indent | link | forecolor backcolor",
				  plugins: "code",
  				  toolbar: "code"
				});
				</script>
				';
			}
			
			if ($slug == "home") {
				$page = "home";
				$data['title'] = "Admin Home";
				$data['js'] .= '<script src="http://code.highcharts.com/highcharts.js"></script><script>$(function(){$("#chart").highcharts({chart:{backgroundColor:"transparent",type:"bar",color:"#FFF"},legend:{enabled:!1},title:{text:"January - February Page Views",style:{color:"#5B6073"}},xAxis:{categories:["Page 1","Page 2","Page 3","Page 4"],lineColor:"#5B6073",gridLineColor:"#5B6073",tickColor:"#5B6073",labels:{style:{color:"#5B6073"}},title:{style:{color:"#5B6073"}}},yAxis:{lineColor:"#5B6073",gridLineColor:"#5B6073",tickColor:"#5B6073",labels:{style:{color:"#5B6073"}},title:{style:{color:"#5B6073"}}},series:[{name:"Views",data:[374,269,122,13],color:"#d75813",borderWidth:"0"}],credits:{enabled:!1}})})</script><script>$(function(){$("#chart2").highcharts({chart:{backgroundColor:"transparent",plotBackgroundColor:null,plotBorderWidth:null,plotShadow:!1,type:"pie",style:{fontFamily:"Open Sans",color:"#FFF"}},title:{text:"Traffic<br>New vs. Recurring",style:{color:"#FFF"}},tooltip:{pointFormat:"{series.name}: <b>{point.percentage:.1f}%</b>"},plotOptions:{pie:{allowPointSelect:!0,cursor:"pointer",dataLabels:{enabled:!0,format:"<b>{point.name}</b>: {point.percentage:.1f} %",style:{color:"white",textShadow:!1,fontFamily:"Open Sans"}}}},series:[{name:"Traffic",colorByPoint:!0,borderWidth:"0",data:[{name:"New",y:56.33,color:"#00acac"},{name:"Recurring",y:24.03,sliced:!0,selected:!0,color:"#727cb6"}]}],credits:{enabled:!1}})})</script><script>$(function(){$("#chart3").highcharts({chart:{backgroundColor:"transparent",plotBackgroundColor:null,plotBorderWidth:null,plotShadow:!1,type:"pie",style:{fontFamily:"Open Sans",color:"#FFF"}},title:{text:"Traffic<br>Direct vs. Referral",style:{color:"#FFF"}},tooltip:{pointFormat:"{series.name}: <b>{point.percentage:.1f}%</b>"},plotOptions:{pie:{allowPointSelect:!0,cursor:"pointer",dataLabels:{enabled:!0,format:"<b>{point.name}</b>: {point.percentage:.1f} %",style:{color:"white",textShadow:!1,fontFamily:"Open Sans"}}}},series:[{name:"Traffic",colorByPoint:!0,borderWidth:"0",data:[{name:"Direct",y:40.68,color:"#AB0000",sliced:!0,selected:!0},{name:"Referral",y:59.32,color:"#D75813"}]}],credits:{enabled:!1}})})</script>';
			}
			switch ($slug) {
				case "login":
					$page = 'login';
					$data['title'] = 'Login';
					unset($header);
					unset($footer);
					$header[0] = "includes/admin-header.php";
					$footer[0] = "includes/admin-footer.php";
				break;
				case "logout":
					redirect('/a/manage_panel/doProcess/doLogout', 'refresh');
				break;
				case "media-gallery":
					$data['gallery'] = $this->admin_model->getMedia();
					$data['title'] = "Media Gallery";
				break;
				case "testimonials":
					$data['testimonials'] = $this->admin_model->getTestimonials();
					$data['title'] = "Testimonials";
				break;
				case "view-posts":
					$data['content'] = $this->admin_model->getPosts();
					$data['title'] = "View Pages";
				break;
				case "edit-post":
					$data['content'] = $this->admin_model->getPost($input_var);
					$data['cats'] = $this->admin_model->getCats();
					$data['title'] = "Edit Post";
				break;
				case "new-post":
					$data['cats'] = $this->admin_model->getCats();
					$data['title'] = "New Post";
				break;
				case "view-pages":
					$data['content'] = $this->admin_model->getPages();
					$data['title'] = "View Pages";
				break;
				case "edit-page":
					$data['content'] = $this->admin_model->getPage($input_var);
					$data['title'] = "Edit Page";
				break;
				case "new-page":
					$data['title'] = "New Page";
				break;
				case "view-blocks":
					$data['content'] = $this->admin_model->getBlocks();
					$data['title'] = "View Blocks";
				break;
				case "edit-block":
					$data['content'] = $this->admin_model->getBlock($input_var);
					$data['title'] = "Edit Block";
				break;
				case "new-block":
					$data['title'] = "New Block";
				break;
				case "view-staff":
					$data['content'] = $this->admin_model->getStaffs();
					$data['title'] = "View Staff";
				break;
				case "edit-staff":
					$data['content'] = $this->admin_model->getStaff($input_var);
					$data['title'] = "Edit Staff";
				break;
				case "new-staff":
					$data['title'] = "New Staff";
				break;
			}
		}
		
		if (empty($data['page_content'])) {
			$data['page_content'] = $this->pages_model->getPage($slug, $type);
		}
		if (!isset($page)) {
			$page = $slug;
		}
		
		if (!file_exists(APPPATH . "views/" . $type . "/" . $page . ".php")) {
			if (empty($data['page_content'])) {
				show_404();
			} else {
				$page = "page";
			}
		}
		
		if ($data['page_content'] == "not found" || $data['page_content'] == 0 || !isset($data['page_content']) || !is_array($data['page_content'])) {
			$data = array();
			$data['title'] = "VM Site";
			$data['content'] = "VM Site Page Not Found";
		}
		
		// Check header and footer includes
		if (!isset($header) || !isset($footer)) {
			$header[0] = "includes/header.php";
			$header[1] = "includes/wrapper_open.php";
			$footer[0] = "includes/wrapper_close.php";
			$footer[1] = "includes/footer.php";
		}
		
		// Load Default System Variables
		$data['system']['slug'] = $slug;
		$data['system']['type'] = $type;
		
		// Load header and footer blocks
		$data['page_class'] = $slug;
		
		if (!isset($header)) {
			$this->load->view('includes/header.php', $data);
		} elseif (isset($header)) {
			foreach ($header as $key=>$value) {
				$this->load->view($value, $data);
			}
		} 
		
		$this->load->view($type . '/' . $page . ".php", $data);
		
		if (!isset($footer)) {
			$this->load->view('includes/footer.php', $data);
		} elseif (isset($footer)) {
			foreach ($footer as $key=>$value) {
				$this->load->view($value, $data);
			}
		}
	}
}
?>