<?php
/**
Image routines helper class for image functions
*/
class imageRoutines {
	/**
	Image routines helper class for image functions
	*/
	function overlayImages($img1, $img2, $offsetx, $offsety, $name) {
		/**
		Function to overlay 2 images on top of each other.  Requires the following arguements:
		$img1: the primary image
		$img2: the overlayed image
		$offsetx: the x-offset
		$offsety: the y-offset
		$name: name of file to be saved
		
		Returns the location of the new image.
		*/
		$bginfo = getimagesize($img1);
		$bgwidth = $bginfo[0];
		$bgheight = $bginfo[1];
		$fginfo = getimagesize($img2);
		$fgwidth = $fginfo[0];
		$fgheight = $fginfo[1];
				
		$image = imagecreatetruecolor($fgwidth,$fgheight);
		
		imagealphablending($image, true);
		imagesavealpha($image, true);
		
		$bg = imagecreatefromstring(file_get_contents($img1));
		$fg = imagecreatefromstring(file_get_contents($img2));
		
		imagecopy($image, $bg, 0, 0, 0, 0, $bgwidth, $bgheight);
		imagecopy($image, $fg, $offsetx, $offsety, 0, 0, $fgwidth, $fgheight);
		
		$saveloc = getcwd() . "/template/uploads/" . $name . ".png";
		$cut = getcwd();
		$imageloc = str_replace($cut, "", $saveloc);
		
		imagepng($image, $saveloc);
		imagedestroy($image);
		imagedestroy($bg);
		imagedestroy($fg);
		
		return $imageloc;
		/*
		//For usage:
		$test = new imageRoutines;
		$testy = $test->overlayImages('http://ahtr.vehicle44.com/template/images/RED.jpg', 'http://ahtr.vehicle44.com/template/images/trans_shield.png', 0, 0 'newname');
		<img src="<?php echo $testy; ?>" />
		*/
	}
	
	function scaleImage($file, $name, $scale, $x, $y) {
		/**
		Function for scaling images.  Requires the following arguements:
		$file: input file
		$name: name of saved file
		$scale: if set to "scale" then the image will scale, otherwise it will stretch to resize
		$x: new x dimensions
		$y: new y dimensions
		
		Returns the new image location.
		*/
		
		$file_headers = @get_headers($file);
		if($file_headers[0] == 'HTTP/1.0 404 Not Found') {
		   return "File Not Found<br />";
		} 
		
		$ext = pathinfo($file, PATHINFO_EXTENSION);
		
		switch(strtolower($ext)) {
			case 'jpg' || 'jpeg':
				$image = imagecreatefromjpeg($file);
				$type = ".jpg";
				break;
			case 'png':
				$image = imagecreatefrompng($file);
				$type = ".png";
				break;
			case 'gif':
				$image = imagecreatefromgif($file);
				$type = ".gif";
				break;
			default:
				return 'Unsupported type<br />';
		}
		
		if ($scale == "scale") {
			$max_width = $x;
			$max_height = $y;		
			$old_width = imagesx($image);
			$old_height = imagesy($image);
			$scale = min($max_width / $old_width, $max_height / $old_height);
			$new_width  = ceil($scale * $old_width);
			$new_height = ceil($scale * $old_height);
		} else {
			$old_width = imagesx($image);
			$old_height = imagesy($image);
			$new_width = $x;
			$new_height = $y;
		}
		
		$new = imagecreatetruecolor($new_width, $new_height);
		imagecopyresampled($new, $image, 0, 0, 0, 0, $new_width, $new_height, $old_width, $old_height);
		
		$saveloc = getcwd() . "/template/uploads/" . $name . $type;
		$cut = getcwd();
		$imageloc = str_replace($cut, "", $saveloc);
		
		imagegif($new, $saveloc);
		
		return $imageloc;
		
		/*
		//For usage:
		$test = new imageRoutines;
		$testy = $test->scaleImage('http://ahtr.vehicle44.com/template/images/1.jpg', 'newfilename', 'scale', 20, 30);
		*/
	}
	
	function colorOverlay($file, $save, $find, $replace) {
		/**
		Experimental procedure for overlaying color on an image.  Requires the following arguements:
		$file: the image file
		$save: the save file name
		$find: color to find (array of r,g,b)
		$replace: color to replace with (array of r,g,b)
		
		Returns the new image location
		*/
		
		// Currently only jpg
		// Experimental
		list($w,$h) = getimagesize($file);
		$img = imagecreatefromjpeg($file);
		imagetruecolortopalette($img,false,255);
		$r = $find[0];
		$g = $find[1];
		$b = $find[2];
		$index = imagecolorclosest($img,$r,$g,$b);
		$r = $replace[0];
		$g = $replace[1];
		$b = $replace[2];
		imagecolorset($img,$index,$r,$g,$b);
		$imgname = $save . ".png";
		
		imagejpeg($img,getcwd() . "/template/uploads/" . $save . ".jpg");
		imagedestroy($img);	
		
		return "/template/uploads/" . $save . ".jpg";
		
		/*
		// Usage:
		$test = new imageRoutines;
		$it = $test->colorOverlay('http://ahtr.vehicle44.com/template/uploads/shield.jpg', 'newfile12', array(205,35,35), array(240,255,0));
		echo "<img src='" . $it . "'>";
		*/
	}
}
?>
