<?php
/**
File for admin model
**/
class Admin_model extends CI_Model {
	/**
	Admin model
	**/
	function __construct() {
		parent::__construct();
		$this->load->database();
		$this->load->helper('keycrypt');
		$this->load->library('session');
	}
	
	function checkAdminLogin() {
		/**
		Function to check if admin user is logged in.  Returns 1 if logged in and 0 if not.
		**/
		if (isset($_SESSION['admin']['sys_id'])) {
			return 1;
		} else {
			return 0;
		}
	}
	
	function doLogin($user, $pass) {
		/**
		Function for admin login.  It requires the user and pass arguements
		**/
		$query = "select * from `admin_users` where `user` = ?";
		$result = $this->db->query($query, array($user));
		$results = $result->result_array();
		if ($result->num_rows() == 0 || $result->num_rows() > 1) {
			return 0;
		}
		foreach ($results as $key=>$value) {
			if ($pass == Encryption::decrypt($value['pass'])) {
				$_SESSION['admin'] = $value;
				unset($_SESSION['admin']['pass']);
				return 1;
			}
		}
		return 0;
	}
	
	function getMedia() {
		/**
		Function to get a list of uploaded items
		**/
		return scandir(dirname(__FILE__) . '/../../public_html/template/uploads');
	}
	
	function doSaveMedia() {
		/**
		Function to upload a file
		**/
		$name = pathinfo($_FILES['img']['name'], PATHINFO_FILENAME);
		$imgname = preg_replace('/[^a-zA-Z0-9-_\.]/','', $name) . "-" . time();
		if (isset($_FILES) && $_FILES['img']['size'] != 0) {
			$test = new fileio;
			$img = $test->upload($_FILES, 'img', 'admin', $imgname, null);
			$img = $img['location'];
			return $img;
			// upload($_FILES, $file_input_name, $uploaded_by, $file_rename (without extension), $type (for later)
		} else {
			return 'Upload Error, Please try again.';
		}
	}
	
	function doDelPage($sys_id) {
		$query = "delete from `pages` where `sys_id` = ?";
		$result = $this->db->query($query, array($sys_id));
		if ($result) {
			return 1;
		} else {
			return 0;
		}
	}
	
	function getPages($args = array()) {
		/**
		Function to get a list of posts for the list view.  Can accept the following arguements:  
		search: search term
		pagination: Current page number
		**/
		$extra = '';
		if (isset($args['search'])) {
			$search = '%' . $args['search'] . '%';
		} else {
			$search = '%';
		}
		if (isset($args['pagination'])) {
			$extra .= ' limit ' . intval($args['pagination'] * 10) . ', 10';
		}
		$query = "select * from `pages` where `title` like ?" . $extra;
		$result = $this->db->query($query, array($search));
		$results = $result->result_array();
		if ($result->num_rows() == 0) {
			return 0;
		} else {
			return $results;
		}
	}
	
	function doDelPost($sys_id) {
		$type = "blog";
		$query = "delete from `blog_posts` where `sys_id` = ?";
		$result = $this->db->query($query, array($sys_id));
		$query = "delete from `assoc_id_to_cat` where `id` = ? and `type` = ?";
		$result = $this->db->query($query, array($sys_id, $type));
		if ($result) {
			return 1;
		} else {
			return 0;
		}
	}
	
	function getPosts($args = array()) {
		/**
		Function to get a list of posts for the list view.  Can accept the following arguements:  
		search: search term
		pagination: Current page number
		cat: cat id
		**/
		$extra = '';
		if (isset($args['search'])) {
			$search = '%' . $args['search'] . '%';
		} else {
			$search = '%';
		}
		if (isset($args['cat'])) {
			$cat = $args['cat'];
		} else {
			$cat = '%';
		}
		if (isset($args['pagination'])) {
			$extra .= ' limit ' . intval($args['pagination'] * 10) . ', 10';
		}
		$query = "select SQL_CALC_FOUND_ROWS `assoc_id_to_cat`.*, `blog_posts`.*, `blog_categories`.* from `assoc_id_to_cat` inner join `blog_posts` on `assoc_id_to_cat`.`id` = `blog_posts`.`sys_id` inner join `blog_categories` on `blog_categories`.`cat_id` = `assoc_id_to_cat`.`cat_id` where `assoc_id_to_cat`.`type` = 'blog' and `blog_posts`.`active` = 1 and `blog_categories`.`cat_slug` like ? and `blog_posts`.`title` like ? order by `date_written` DESC" . $extra;
		$result = $this->db->query($query, array($cat, $search));
		$results = $result->result_array();
		if ($result->num_rows() == 0) {
			return 0;
		} else {
			return $results;
		}
	}
	
	function getPage($page_id) {
		/**
		Function to get page data (for editing).  It requires the page_id.
		**/
		$query = "select * from `pages` where `sys_id` = ?";
		$result = $this->db->query($query, array($page_id));
		$results = $result->result_array();
		if ($result->num_rows() == 0) {
			return 0;
		} else {
			return $results;
		}
	}
	
	function getPost($post_id) {
		/**
		Function to get post data (for editing).  It requires the post_id.
		**/
		$query = "select `assoc_id_to_cat`.*, `blog_posts`.*, `blog_categories`.* from `assoc_id_to_cat` inner join `blog_posts` on `assoc_id_to_cat`.`id` = `blog_posts`.`sys_id` inner join `blog_categories` on `blog_categories`.`cat_id` = `assoc_id_to_cat`.`cat_id` where `assoc_id_to_cat`.`type` = 'blog' and `blog_posts`.`active` = 1 and `blog_posts`.`sys_id` = ?";
		$result = $this->db->query($query, array($post_id));
		$results = $result->result_array();
		if ($result->num_rows() == 0) {
			return 0;
		} else {
			return $results;
		}
	}
	
	function getCats() {
		/**
		Function to return an array of all available categories
		**/
		$query = "select * from `blog_categories`";
		$result = $this->db->query($query);
		return $result->result_array();
	}
	
	function doAddPage($args) {
		/**
		Process for adding a new page.  Requires the following arguements:
		Title
		Content
		**/
		$title = $args['title'];
		$content = $args['content'];
		$slug = $args['slug'];
		$page = 'page';
		$active = 1;
		
		if ($slug == '') {
			$slug = $title;
		}
		$slug = create_slug($slug);
		$success = 0;
		$xxx = 0;
		$newslug = $slug;
		while ($success == 0) {
			$query = "select * from `admin_slugs` where `slug` = ?";
			$result = $this->db->query($query, array($newslug));
			if ($result->num_rows() > 0) {
				$newslug = $slug . "-" . $xxx; 
			} else {
				$success = 1;
				$slug = $newslug;
			}
			$xxx++;
		}
		$query = "insert into `pages` (`title`, `type`, `content`, `slug`, `active`) values (?, ?, ?, ?, ?)";
		$result = $this->db->query($query, array($title, $page, $content, $slug, $active));
		if ($result) {
			return 1;
		} else {
			return 0;
		}
	}
	
	function doEditPage($args) {
		/**
		Process for editing a page.  Requires the following arguements:
		Title
		Content
		SysID
		Slug
		**/
		$title = $args['title'];
		$content = $args['content'];
		$slug = $args['slug'];
		$sys_id = $args['sys_id'];
		$page = 'page';
		$active = 1;
		
		if ($slug == '') {
			$slug = $title;
		}
		$slug = create_slug($slug);
		$success = 0;
		$xxx = 0;
		$newslug = $slug;
		while ($success == 0) {
			$query = "select * from `admin_slugs` where `slug` = ? and `sys_id` <> ? and `post` = 'PAGE'";
			$result = $this->db->query($query, array($newslug, $sys_id));
			if ($result->num_rows() > 0) {
				$newslug = $slug . "-" . $xxx; 
			} else {
				$success = 1;
				$slug = $newslug;
			}
			$xxx++;
		}
		$query = "update `pages` set `title` = ?, `type` = ?, `content` = ?, `slug` = ?, `active` = ? where `sys_id` = ?";
		$result = $this->db->query($query, array($title, $page, $content, $slug, $active, $sys_id));
		if ($result) {
			return 1;
		} else {
			return 0;
		}
	}
	
	function doAddPost($args) {
		/**
		Process for adding a new post.  Requires the following arguements:
		Title
		Content
		**/
		$title = $args['title'];
		$content = $args['content'];
		$slug = $args['slug'];
		$cat = $args['cat'];
		$tags = $args['tags'];
		$page = 'post';
		$active = 1;
		
		if ($slug == '') {
			$slug = $title;
		}
		$slug = create_slug($slug);
		$success = 0;
		$xxx = 0;
		$newslug = $slug;
		while ($success == 0) {
			$query = "select * from `admin_slugs` where `slug` = ?";
			$result = $this->db->query($query, array($newslug));
			if ($result->num_rows() > 0) {
				$newslug = $slug . "-" . $xxx; 
			} else {
				$success = 1;
				$slug = $newslug;
			}
			$xxx++;
		}
		$query = "insert into `blog_posts` (`title`, `tags`, `content`, `slug`, `active`, `date_written`) values (?, ?, ?, ?, ?, NOW())";
		$result = $this->db->query($query, array($title, $tags, $content, $slug, $active));
		$id = $this->db->insert_id();
		$query = "insert into `assoc_id_to_cat` (`id`, `cat_id`, `type`) values (?, ?, 'blog')";
		$result = $this->db->query($query, array($id, $cat));
		if ($result) {
			return 1;
		} else {
			return 0;
		}
	}
	
	function doEditPost($args) {
		/**
		Process for editing a post.  Requires the following arguements:
		Title
		Content
		SysID
		Slug
		cat
		**/
		$title = $args['title'];
		$content = $args['content'];
		$cat = $args['cat'];
		$slug = $args['slug'];
		$sys_id = $args['sys_id'];
		$tags = $args['tags'];
		$page = 'page';
		$active = 1;
		
		if ($slug == '') {
			$slug = $title;
		}
		$slug = create_slug($slug);
		$success = 0;
		$xxx = 0;
		$newslug = $slug;
		while ($success == 0) {
			$query = "select * from `admin_slugs` where `slug` = ? and `sys_id` <> ? and `post` = 'POST'";
			$result = $this->db->query($query, array($newslug, $sys_id));
			if ($result->num_rows() > 0) {
				$newslug = $slug . "-" . $xxx; 
			} else {
				$success = 1;
				$slug = $newslug;
			}
			$xxx++;
		}
		$query = "update `blog_posts` set `title` = ?, `tags` = ?, `content` = ?, `slug` = ?, `active` = ? where `sys_id` = ?";
		$result = $this->db->query($query, array($title, $tags, $content, $slug, $active, $sys_id));
		$query = "update `assoc_id_to_cat` set `cat_id` = ? where `id` = ? and `type` = 'blog'";
		$result = $this->db->query($query, array($cat, $sys_id));
		if ($result) {
			return 1;
		} else {
			return 0;
		}
	}
	
	function doDelBlock($sys_id) {
		$query = "delete from `blocks` where `sys_id` = ?";
		$result = $this->db->query($query, array($sys_id));
		if ($result) {
			return 1;
		} else {
			return 0;
		}
	}
	
	function getBlock($block_id) {
		/**
		Function to get block data (for editing).  It requires the block_id.
		**/
		$query = "select * from `blocks` where `sys_id` = ?";
		$result = $this->db->query($query, array($block_id));
		$results = $result->result_array();
		if ($result->num_rows() == 0) {
			return 0;
		} else {
			return $results;
		}
	}
	
	function getBlocks($args = array()) {
		/**
		Function to get a list of blocks for the list view.  Can accept the following arguements:  
		search: search term
		pagination: Current page number
		**/
		$extra = '';
		if (isset($args['search'])) {
			$search = '%' . $args['search'] . '%';
		} else {
			$search = '%';
		}
		if (isset($args['pagination'])) {
			$extra .= ' limit ' . intval($args['pagination'] * 10) . ', 10';
		}
		$query = "select * from `blocks` where `title` like ?" . $extra;
		$result = $this->db->query($query, array($search));
		$results = $result->result_array();
		if ($result->num_rows() == 0) {
			return 0;
		} else {
			return $results;
		}
	}
	
	function doAddBlock($args) {
		/**
		Process for adding a new block.  Requires the following arguements:
		Title
		Content
		**/
		$title = $args['title'];
		$content = $args['content'];
		$active = 1;
		
		$query = "insert into `blocks` (`title`, `content`, `active`) values (?, ?, ?)";
		$result = $this->db->query($query, array($title, $content, $active));
		if ($result) {
			return 1;
		} else {
			return 0;
		}
	}
	
	function doEditBlock($args) {
		/**
		Process for editing a block.  Requires the following arguements:
		Title
		Content
		SysID
		Slug
		**/
		$title = $args['title'];
		$content = $args['content'];
		$sys_id = $args['sys_id'];
		$active = 1;
		
		$query = "update `blocks` set `title` = ?, `content` = ?, `active` = ? where `sys_id` = ?";
		$result = $this->db->query($query, array($title, $content, $active, $sys_id));
		if ($result) {
			return 1;
		} else {
			return 0;
		}
	}
	
	function doDelStaff($sys_id) {
		$query = "delete from `staff` where `sys_id` = ?";
		$result = $this->db->query($query, array($sys_id));
		if ($result) {
			return 1;
		} else {
			return 0;
		}
	}
	
	function getStaff($staff_id) {
		/**
		Function to get staff member data (for editing).  It requires the staff_id.
		**/
		$query = "select * from `staff` where `sys_id` = ?";
		$result = $this->db->query($query, array($staff_id));
		$results = $result->result_array();
		if ($result->num_rows() == 0) {
			return 0;
		} else {
			return $results;
		}
	}
	
	function getStaffs() {
		/**
		Function to get a list of staff members for the list view.  Accepts no arguements  
		**/
		$query = "select * from `staff`";
		$result = $this->db->query($query);
		$results = $result->result_array();
		if ($result->num_rows() == 0) {
			return 0;
		} else {
			return $results;
		}
	}
	
	function doAddStaff($args) {
		/**
		Process for adding a new stzff member.  Requires the following arguements:
		Name 
		Title
		Content
		img
		**/
		$this->load->helper('fileio');
		$title = $args['title'];
		$name = $args['name'];
		$content = $args['content'];
		$active = 1;
		$imgname = preg_replace('/[^a-zA-Z0-9-_\.]/','', $name) . "-" . time();
		
		if (isset($_FILES) && $_FILES['img']['size'] != 0) {
			$test = new fileio;
			$img = $test->upload($_FILES, 'img', 'admin', $imgname, null);
			// upload($_FILES, $file_input_name, $uploaded_by, $file_rename (without extension), $type (for later)
		} else {
			$img = '';
			$img['location'] = '';
		}
		
		$query = "insert into `staff` (`name`, `title`, `content`, `img`, `active`) values (?, ?, ?, ?, ?)";
		$result = $this->db->query($query, array($name, $title, $content, $img['location'], $active));
		if ($result) {
			return 1;
		} else {
			return 0;
		}
	}
	
	function doEditStaff($args) {
		/**
		Process for editing a staff member.  Requires the following arguements:
		Name (required)
		Title (optional)
		Content (required)
		SysID (optional)
		img (optional)
		old_img (required)
		**/
		$this->load->helper('fileio');
		$name = $args['name'];
		$title = $args['title'];
		$content = $args['content'];
		$sys_id = $args['sys_id'];
		$active = 1;
		
		$imgname = preg_replace('/[^a-zA-Z0-9-_\.]/','', $name) . "-" . time();
		if (isset($_FILES) && $_FILES['img']['size'] != 0) {
			$test = new fileio;
			$img = $test->upload($_FILES, 'img', 'admin', $imgname, null);
			$img = $img['location'];
			// upload($_FILES, $file_input_name, $uploaded_by, $file_rename (without extension), $type (for later)
		} else {
			$img = $args['old_img'];
		}
		
		$query = "update `staff` set `name` = ?, `title` = ?, `content` = ?, `img` = ?, `active` = ? where `sys_id` = ?";
		$result = $this->db->query($query, array($name, $title, $content, $img, $active, $sys_id));
		if ($result) {
			return 1;
		} else {
			return 0;
		}
	}
	
	function getTestimonials() {
		/**
		Function to get list of testimonials for activation / deactivation.
		**/
		$query = "select * from `testimonials` order by `active` ASC";
		$result = $this->db->query($query);
		return $result->result_array();
	}
	
	function doApproveTestimonials($sys_id, $status) {
		/**
		Function to approve / disapprove testimonials.  Requires sys_id and status (1 or 0)
		**/
		$query = "update `testimonials` set `active` = ? where `sys_id` = ?";
		$result = $this->db->query($query, array($status, $sys_id));
		if ($result) {
			return 1;
		} else {
			return 0;
		}
	}
}
?>